Welcome to django-postgres-metrics's documentation!
===================================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   background
   getting-started
   usage
   designing-your-own
   contributing/index
   ref/modules
   changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
